#ifndef NT2_INCLUDE_FUNCTIONS_GAMMAINC_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_GAMMAINC_HPP_INCLUDED

#include <nt2/euler/include/functions/gammainc.hpp>

#endif
